@@ -9,4 +9,7 @@ from .preprocessing import jaccard_sim_filtering
 from .preprocessing import perplexity_filtering
 from .preprocessing import join_sentences_by_label
 from .outliers_detection import outlier_detection
+from .outliers_detection import tonmf
+from .outliers_detection import rpca_implementation
+from .outliers_detection import svd
 
